package cwms.environment;

import java.io.File;
import hec.environment.*;

/**
 * CWMS-oriented implementation of the Environment interface.
 * 
 * @see hec.environment.Environment
 */
public class CwmsEnvironmentImpl implements Environment {

	static String cwms_home = System.getProperty("CWMS_HOME");
	static String user_name = System.getProperty("user.name");

	/**
	 * Default constructor
	 */
	public CwmsEnvironmentImpl() {}
	
	/**
	 * Get the CWMS-specific pathname represented by the pathname_id.
	 * 
	 * @param pathname_id
	 *               The constant representing the desired pathname.
	 * 
	 * @return The desired pathname.
	 */
	public String getStdPathname(int pathname_id) throws Exception {

		if (cwms_home == null) throw new StdPathnameException("Property CWMS_HOME is not defined.");
		if (user_name == null) throw new StdPathnameException("Property user.name is not defined.");
		String pathname = null;
		switch(pathname_id) {
			case USER_HOME       : pathname = cwms_home + "/users/" + user_name;          break;
			case USER_APPDATA    : pathname = cwms_home + "/users/" + user_name + "/etc"; break;
			case USER_DOCS       : pathname = cwms_home + "/users/" + user_name + "/doc"; break;
			case COMMON_APPDATA  : pathname = cwms_home + "/users/All/etc";               break;
			case COMMON_DOCS     : pathname = cwms_home + "/users/All/doc";               break;
			case PROGRAM_INSTALL : pathname = cwms_home;                                  break;
			default              :
				throw new CwmsStdPathnameException("Invalid pathname ID: " + pathname_id);
		}
		return pathname.replace('/', File.separatorChar);
	}

	/**
	 * Get the CWMS-specific user home pathname.
	 * 
	 * @return The user home pathname.
	 */
	public String getUserHome() throws Exception {return getStdPathname(USER_HOME);}

	/**
	 * Get the CWMS-specific user application data pathname.
	 * 
	 * @return The user application data pathname.
	 */
	public String getUserAppData() throws Exception {return getStdPathname(USER_APPDATA);}

	/**
	 * Get the CWMS-specific user docuements pathname.
	 * 
	 * @return The user documents pathname.
	 */
	public String getUserDocs() throws Exception {return getStdPathname(USER_DOCS);}

	/**
	 * Get the CWMS-specific shared application data pathname.
	 * 
	 * @return The shared application data pathname.
	 */
	public String getCommonAppData() throws Exception {return getStdPathname(COMMON_APPDATA);}

	/**
	 * Get the CWMS-specific shared docuements pathname.
	 * 
	 * @return The shared documents pathname.
	 */
	public String getCommonDocs() throws Exception {return getStdPathname(COMMON_DOCS);}

	/**
	 * Get the CWMS-specific program installation pathname.
	 * 
	 * @return The program installation pathname.
	 */
	public String getProgramInstall() throws Exception {return getStdPathname(PROGRAM_INSTALL);}

}
