package hec.environment;

/**
 * Class to implement an OS-specific instance of StdPathnames.
 * 
 * @see StdPathnames
 * @see WindowsStdPathnameImpl
 * @see UnixStdPathnameImpl
 */
public class StdPathnameFactory {

	protected static StdPathnames instance = null;
	protected static boolean initialized   = false;
        	
	/**
	 * Initializes the implementation instance for the current operating system.
	 * 
	 * @exception Exception
	 */
	protected synchronized static void initialize() throws Exception {
		
		String os_name = System.getProperty("os.name", "unknown").toLowerCase();

		if      (os_name.startsWith("win")) instance = new WindowsStdPathnameImpl();
		else if (os_name.startsWith("sun")) instance = new UnixStdPathnameImpl();

		initialized = true;
	}

	/**
	 * Retrieves an implementation of StdPathnames for the current operating system.
	 * 
	 * @return The implementation of StdPathnames for the current operating system. If there is no implementation for
	 *         the current operating system, returns null.
	 * @exception Exception
	 */
	public synchronized static StdPathnames getInstance() throws Exception {

		if (initialized == false) initialize();
		return instance;
	}

	public static void main (String args[]) throws Exception {

		StdPathnames inst = StdPathnameFactory.getInstance();

		System.out.println("\nThe following calls should succeed...\n");
		System.out.println("USER_HOME       : " + inst.getUserHome());
		System.out.println("USER_APPDATA    : " + inst.getUserAppData());
		System.out.println("USER_DOCS       : " + inst.getUserDocs());
		System.out.println("COMMON_APPDATA  : " + inst.getCommonAppData());
		System.out.println("COMMON_DOCS     : " + inst.getCommonDocs());
		System.out.println("PROGRAM_INSTALL : " + inst.getProgramInstall());
		
		System.out.println("\nThe following call should throw a StdPathnameException...\n");
		System.out.println("JUNK            : " + inst.getStdPathname(0x7777));
	}
}                                  
