package hec.environment;

/**
 * Unix-specific implementation of StdPathnames interface.
 */
class UnixStdPathnameImpl implements StdPathnames {

	static String user_home = System.getProperty("user.home");

	/**
	 * Get the Unix-specific pathname represented by the pathname_id.
	 * 
	 * @param pathname_id
	 *               The constant representing the desired pathname.
	 * 
	 * @return The desired pathname.
	 */
	public String getStdPathname(int pathname_id) throws Exception {

		if (user_home == null) throw new StdPathnameException("Property user.home is not defined.");
		String pathname = null;
		switch(pathname_id) {
			case USER_HOME       : pathname = user_home;          break;
			case USER_APPDATA    : pathname = user_home + "/etc"; break;
			case USER_DOCS       : pathname = user_home + "/doc"; break;
			case COMMON_APPDATA  : pathname =  "/usr/local/etc";  break;
			case COMMON_DOCS     : pathname =  "/usr/local/doc";  break;
			case PROGRAM_INSTALL : pathname =  "/usr/local";      break;
			default              :
				throw new StdPathnameException("Invalid pathname ID: " + pathname_id);
		}
		return pathname;
	}

	/**
	 * Get the Unix-specific user home pathname.
	 * 
	 * @return The user home pathname.
	 */
	public String getUserHome() throws Exception {

		return getStdPathname(USER_HOME);
	}

	/**
	 * Get the Unix-specific user application data pathname.
	 * 
	 * @return The user application data pathname.
	 */
	public String getUserAppData() throws Exception {

		return getStdPathname(USER_APPDATA);
	}

	/**
	 * Get the Unix-specific user docuements pathname.
	 * 
	 * @return The user documents pathname.
	 */
	public String getUserDocs() throws Exception {

		return getStdPathname(USER_DOCS);
	}

	/**
	 * Get the Unix-specific shared application data pathname.
	 * 
	 * @return The shared application data pathname.
	 */
	public String getCommonAppData() throws Exception {

		return getStdPathname(COMMON_APPDATA);
	}

	/**
	 * Get the Unix-specific shared docuements pathname.
	 * 
	 * @return The shared documents pathname.
	 */
	public String getCommonDocs() throws Exception {

		return getStdPathname(COMMON_DOCS);
	}

	/**
	 * Get the Unix-specific program installation pathname.
	 * 
	 * @return The program installation pathname.
	 */
	public String getProgramInstall() throws Exception {

		return getStdPathname(PROGRAM_INSTALL);
	}

}
